Learn R Programming

catSurv (version 1.1.3)

likelihood: Likelihood of the Specified Response Set

Description

Calculates the likelihood of a respondent, with ability parameter \(\theta\), having offered the specific set of responses stored in the Cat objects answers slot. All calculations are conditional on the item-level parameters stored in the Cat object.

Usage

likelihood(catObj, theta)

Arguments

catObj

An object of class Cat

theta

A numeric or an integer indicating the value for \(\theta\)

Value

The function likelihood returns a numeric value of the likelihood of the respondent having offered the provided response profile.

References

Baker, Frank B. and Seock-Ho Kim. 2004. Item Response Theory: Parameter Estimation Techniques. New York: Marcel Dekker.

Choi, Seung W. and Richard J. Swartz. 2009. ``Comparison of CAT Item Selection Criteria for Polytomous Items." Applied Psychological Measurement 33(6):419-440.

Muraki, Eiji. 1992. ``A generalized partial credit model: Application of an EM algorithm." ETS Research Report Series 1992(1):1-30.

van der Linden, Wim J. 1998. ``Bayesian Item Selection Criteria for Adaptive Testing." Psychometrika 63(2):201-216.

See Also

Cat-class, probability

Examples

Run this code
# NOT RUN {
## Loading ltm Cat object
## Likelihood for Cat object of the ltm model
data(ltm_cat)
setAnswers(ltm_cat) <- c(1,0,1,0,1, rep(NA, 35))
likelihood(ltm_cat, theta = 1)

## Loading grm Cat object
## Likelihood for Cat object of the grm model
data(grm_cat)
setAnswers(grm_cat) <- c(1,1,5,2,5, rep(NA, 13))
likelihood(grm_cat, theta = 1)



# }

Run the code above in your browser using DataLab